summaryrefslogtreecommitdiff
path: root/vendor/thecodingmachine/safe/generated/opcache.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/thecodingmachine/safe/generated/opcache.php')
-rw-r--r--vendor/thecodingmachine/safe/generated/opcache.php15
1 files changed, 8 insertions, 7 deletions
diff --git a/vendor/thecodingmachine/safe/generated/opcache.php b/vendor/thecodingmachine/safe/generated/opcache.php
index 04a58205f..dcac85493 100644
--- a/vendor/thecodingmachine/safe/generated/opcache.php
+++ b/vendor/thecodingmachine/safe/generated/opcache.php
@@ -9,14 +9,14 @@ use Safe\Exceptions\OpcacheException;
* executing it. This can be used to prime the cache after a Web server
* restart by pre-caching files that will be included in later requests.
*
* @param string $file The path to the PHP script to be compiled.
* @throws OpcacheException
*
*/
-function opcache_compile_file(string $file): void
+function opcache_compile_file(string $filename): void
{
error_clear_last();
- $result = \opcache_compile_file($file);
+ $result = \opcache_compile_file($filename);
if ($result === false) {
throw OpcacheException::createFromPhpError();
}
@@ -24,17 +24,18 @@ function opcache_compile_file(string $file): void
/**
- * This function returns state information about the cache instance
+ * This function returns state information about the in-memory cache instance. It will not return any
+ * information about the file cache.
*
* @param bool $get_scripts Include script specific state information
* @return array Returns an array of information, optionally containing script specific state information.
* @throws OpcacheException
*
*/
-function opcache_get_status(bool $get_scripts = true): array
+function opcache_get_status(bool $include_scripts = true): array
{
error_clear_last();
- $result = \opcache_get_status($get_scripts);
+ $result = \opcache_get_status($include_scripts);
if ($result === false) {
throw OpcacheException::createFromPhpError();
}
@@ -9,14 +9,14 @@ use Safe\Exceptions\OpcacheException;
* restart by pre-caching files that will be included in later requests.
*
- * @param string $file The path to the PHP script to be compiled.
+ * @param string $filename The path to the PHP script to be compiled.
* @throws OpcacheException
*
@@ -24,17 +24,18 @@ function opcache_compile_file(string $file): void
*
- * @param bool $get_scripts Include script specific state information
+ * @param bool $include_scripts Include script specific state information
* @return array Returns an array of information, optionally containing script specific state information.
* @throws OpcacheException